@@ -9,8 +9,8 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from namespace.namespace import RDF, RDFS, SMTK
-from uuid_generator import generate_uuid 
+from semantyk.namespace.namespace import RDF, RDFS, SMTK
+from semantyk.uuid_generator import generate_uuid 
 from rdflib import Namespace, URIRef
 
 class Resource(object):
@@ -108,7 +108,7 @@ class Resource(object):
         return hash(self.uri)
 
     def __str__(self):
-        result = self.id
+        result = self.id + 'Test'
         if self.dictionary:
             result += ':'
             for p in self.dictionary:
